@@ -20,7 +20,7 @@ use Mojo::Webqq::Client::Remote::_recv_message;
 use Mojo::Webqq::Client::Remote::_relink;
 use Mojo::Webqq::Client::Remote::logout;
 
-use base qw(Mojo::Webqq::Request Mojo::Webqq::Client::Cron);
+use base qw(Mojo::Webqq::Request);
 
 sub run{
     my $self = shift;
@@ -421,9 +421,11 @@ sub spawn {
     my $self = shift;
     my %opt = @_;
     require Mojo::Webqq::Run;
-    my $run = Mojo::Webqq::Run->new(ioloop=>$self->ioloop,log=>$self->log); 
+    my $is_blocking = delete $opt{is_blocking};
+    my $run = Mojo::Webqq::Run->new(ioloop=>($is_blocking?Mojo::IOLoop->new:$self->ioloop),log=>$self->log); 
     $run->max_forks(delete $opt{max_forks}) if defined $opt{max_forks};
     $run->spawn(%opt);
+    $run->start if $is_blocking;
     $run;
 }
 sub clean_qrcode{
@@ -441,4 +443,10 @@ sub clean_verifycode{
     unlink $self->verifycode_path or $self->warn("删除验证码图片[ ". $self->verifycode_path . " ]失败: $!");
 }
 
+sub add_job {
+    my $self = shift;
+    require Mojo::Webqq::Client::Cron;
+    $self->Mojo::Webqq::Client::Cron::add_job(@_);
+}
+
 1;
